Skip to contents

A data frame of universal geography code and name options that are acceptable for any geography level (e.g. "Not applicable", "Unknown").

Usage

acceptable_extra_geog_options

Format

A data.frame with columns:

code

GSS geography code

name

Geography name matching the code

dfe-published-data-qa screener app repo, data/universal_geog_options.csv