Skip to contents

Checks that all english_devolved_area_code and english_devolved_area_name combinations in the data file are valid. For English devolved area rows, all combinations must be valid. For non-EDA rows, only non-empty, non-NA combinations are checked. Rows where english_devolved_area_code is "x" (the GSS not-available code) are excluded from non-EDA checks.

Usage

check_geog_eda_combos(data, verbose = FALSE, stop_on_error = FALSE)

Arguments

data

A data frame of the data file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Details

If either english devolved area column is absent from the data, the check passes immediately.

Examples

check_geog_eda_combos(example_data)
#>             check result
#> 1 geog_eda_combos   PASS
#>                                                                                                                 message
#> 1 At least one of the english_devolved_area_code / english_devolved_area_name columns is not present in this data file.
#>   guidance_url
#> 1           NA
check_geog_eda_combos(example_data, verbose = TRUE)
#>  At least one of the english_devolved_area_code / english_devolved_area_name columns is not present in this data file.
#>             check result
#> 1 geog_eda_combos   PASS
#>                                                                                                                 message
#> 1 At least one of the english_devolved_area_code / english_devolved_area_name columns is not present in this data file.
#>   guidance_url
#> 1           NA