Skip to contents

When any of the three local authority columns (new_la_code, la_name, old_la_code) appear in the data file, all three must be present. A partial set of LA columns indicates a data quality issue.

Usage

check_geog_la_col_present(data, verbose = FALSE, stop_on_error = FALSE)

Arguments

data

A data frame of the data file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Details

If none of the LA columns are present the check passes immediately.

Examples

check_geog_la_col_present(example_data)
#>                 check result
#> 1 geog_la_col_present   PASS
#>                                                     message guidance_url
#> 1 No local authority columns are present in this data file.           NA
check_geog_la_col_present(example_data, verbose = TRUE)
#>  No local authority columns are present in this data file.
#>                 check result
#> 1 geog_la_col_present   PASS
#>                                                     message guidance_url
#> 1 No local authority columns are present in this data file.           NA