Skip to contents

Checks that each geography name maps to only one code for Opportunity area, MAT, and Sponsor rows. A geography name with multiple different codes indicates a data quality issue.

Usage

check_geog_other_dupes(data, verbose = FALSE, stop_on_error = FALSE)

Arguments

data

A data frame of the data file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Details

If none of the lower-level geography levels (Opportunity area, MAT, Sponsor) are present in the data, the check passes immediately.

Examples

check_geog_other_dupes(example_data)
#>              check result
#> 1 geog_other_dupes   PASS
#>                                                        message guidance_url
#> 1 Lower-level geography data is not present in this data file.           NA
check_geog_other_dupes(example_data, verbose = TRUE)
#>  Lower-level geography data is not present in this data file.
#>              check result
#> 1 geog_other_dupes   PASS
#>                                                        message guidance_url
#> 1 Lower-level geography data is not present in this data file.           NA