Skip to contents

When one of region_code or region_name is present in the data file, checks that the other column is also present. If neither column is present, the check passes immediately.

Usage

check_geog_region_col_present(data, verbose = FALSE, stop_on_error = FALSE)

Arguments

data

A data frame of the data file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_geog_region_col_present(example_data)
#>                     check result
#> 1 geog_region_col_present   PASS
#>                                              message guidance_url
#> 1 No regional columns are present in this data file.           NA
check_geog_region_col_present(example_data, verbose = TRUE)
#>  No regional columns are present in this data file.
#>                     check result
#> 1 geog_region_col_present   PASS
#>                                              message guidance_url
#> 1 No regional columns are present in this data file.           NA