Skip to contents

Ensure that each entry under label is unique in the metafile.

Usage

check_meta_duplicate_label(meta, verbose = FALSE, stop_on_error = FALSE)

Arguments

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_duplicate_label(example_meta)
#>                  check result                message guidance_url
#> 1 meta_duplicate_label   PASS All labels are unique.           NA
check_meta_duplicate_label(example_meta, verbose = TRUE)
#>  All labels are unique.
#>                  check result                message guidance_url
#> 1 meta_duplicate_label   PASS All labels are unique.           NA