Skip to contents

Throw warning if there are any indicator rows that have filter_group as non-blank, to encourage users to correct the metadata.

Usage

check_meta_fil_grp(meta, verbose = FALSE, stop_on_error = FALSE)

Arguments

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_fil_grp(example_meta)
#>          check result                                            message
#> 1 meta_fil_grp   PASS No indicators have a filter_grouping_column value.
#>   guidance_url
#> 1           NA
check_meta_fil_grp(example_meta, verbose = TRUE)
#>  No indicators have a filter_grouping_column value.
#>          check result                                            message
#> 1 meta_fil_grp   PASS No indicators have a filter_grouping_column value.
#>   guidance_url
#> 1           NA