Skip to contents

Ensure all filter groups from the meta data are unique.

Usage

check_meta_fil_grp_dupe(meta, verbose = FALSE, stop_on_error = FALSE)

Arguments

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_fil_grp_dupe(example_meta)
#>               check result                             message guidance_url
#> 1 meta_fil_grp_dupe   PASS There are no filter groups present.           NA
check_meta_fil_grp_dupe(example_meta, verbose = TRUE)
#>  There are no filter groups present.
#>               check result                             message guidance_url
#> 1 meta_fil_grp_dupe   PASS There are no filter groups present.           NA