Skip to contents

Ensure all filter groups from the meta data are unique.

Usage

check_meta_filter_group_duplicate(meta, verbose = FALSE, stop_on_error = FALSE)

Arguments

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_filter_group_duplicate(example_meta)
#>                    check result                             message
#> 1 filter_group_duplicate   PASS There are no filter groups present.
#>   guidance_url
#> 1           NA
check_meta_filter_group_duplicate(example_meta, verbose = TRUE)
#>  There are no filter groups present.
#>                    check result                             message
#> 1 filter_group_duplicate   PASS There are no filter groups present.
#>   guidance_url
#> 1           NA