Skip to contents

Ensure all filter groups from the meta data are found in the data file.

Usage

check_meta_filter_group_match(
  data,
  meta,
  verbose = FALSE,
  stop_on_error = FALSE
)

Arguments

data

A data frame of the data file

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_filter_group_match(example_data, example_meta)
#>                 check result                             message guidance_url
#> 1 filter_groups_match   PASS There are no filter groups present.           NA
check_meta_filter_group_match(example_data, example_meta, verbose = TRUE)
#>  There are no filter groups present.
#>                 check result                             message guidance_url
#> 1 filter_groups_match   PASS There are no filter groups present.           NA