Skip to contents

Throw warning if there are any blank cells for indicator_dp in rows, to encourage users to explicitly specify the behaviour they want.

Usage

check_meta_ind_dp_set(meta, verbose = FALSE, stop_on_error = FALSE)

Arguments

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_ind_dp_set(example_meta)
#>             check result
#> 1 meta_ind_dp_set   PASS
#>                                                    message guidance_url
#> 1 The indicator_dp column is completed for all indicators.           NA
check_meta_ind_dp_set(example_meta, verbose = TRUE)
#>  The indicator_dp column is completed for all indicators.
#>             check result
#> 1 meta_ind_dp_set   PASS
#>                                                    message guidance_url
#> 1 The indicator_dp column is completed for all indicators.           NA