Skip to contents

Throw FAIL if there are indicator_unit values present when col_type is "Filter"

Usage

check_meta_ind_unit(meta, verbose = FALSE, stop_on_error = FALSE)

Arguments

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_ind_unit(example_meta)
#>           check result                                  message guidance_url
#> 1 meta_ind_unit   PASS No filters have an indicator_unit value.           NA
check_meta_ind_unit(example_meta, verbose = TRUE)
#>  No filters have an indicator_unit value.
#>           check result                                  message guidance_url
#> 1 meta_ind_unit   PASS No filters have an indicator_unit value.           NA