Skip to contents

Throw error if indicator unit values used in the meta file are not present in the list of acceptable indicator unit values

Usage

check_meta_ind_unit_validation(meta, verbose = FALSE, stop_on_error = FALSE)

Arguments

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_ind_unit_validation(example_meta)
#>                       check result                             message
#> 1 indicator_unit_validation   PASS The indicator_unit values are valid
#>   guidance_url
#> 1           NA
check_meta_ind_unit_validation(example_meta, verbose = TRUE)
#>  The indicator_unit values are valid
#>                       check result                             message
#> 1 indicator_unit_validation   PASS The indicator_unit values are valid
#>   guidance_url
#> 1           NA