Skip to contents

A set of the robot test files as used in EES UI tests. These are available from: https://github.com/dfe-analytical-services/explore-education-statistics/tree/dev/tests/robot-tests/tests/files

Usage

ees_robot_test_data

Format

A list of 14 robot test examples, with each element of the list containing

robot name

Name of the robot test data

data

The robot test data

meta

The robot test meta

maintained by explore.statistics@education.gov.uk