Example data that contains strings containing commas beyond the default sniffing length. The original can be obtained from the EES test suite
Source:R/example_datasets.R
example_comma_data.RdExample data that contains strings containing commas beyond the default sniffing length. The original can be obtained from the EES test suite
Format
A data frame with 22,005 rows and 11 columns:
- time_period
Time period of row
- time_identifier
Time identifier of row
- geographic_level
Geographic level
- country_code
Country code
- country_name
Country name
- new_la_code
New LA code
- la_name
LA name
- old_la_code
Old LA code
- sex
Sex
- education_phase
Education phase
- enrolment_count
Enrolment count