Skip to contents

Example screening output pre-generated from example_data and example_meta

Usage

example_output

Format

A data frame with the same number of rows as there are tests in the package, and 5 columns:

check

Name of the check

result

Check result: PASS / FAIL / WARNING

message

Check info message

guidance_url

URL to any guidance associated with the check

stage

Stage group the listed check belongs to

maintained by explore.statistics@education.gov.uk