Check all required columns are present in data
Source:R/precheck_col_req_data.R
precheck_col_req_data.RdUsing the req_data_cols object.
See also
Other precheck_col:
check_meta_col_name_spaces(),
precheck_col_invalid_meta(),
precheck_col_req_meta(),
precheck_col_to_rows()
Examples
precheck_col_req_data(example_data)
#> check result message
#> 1 col_req_data PASS All of the required columns are present in the data file.
#> guidance_url
#> 1 NA
precheck_col_req_data(example_data, verbose = TRUE)
#> ✔ All of the required columns are present in the data file.
#> check result message
#> 1 col_req_data PASS All of the required columns are present in the data file.
#> guidance_url
#> 1 NA