Check that the geographic_level values are all valid.
Source:R/precheck_geog_level.R
precheck_geog_level.RdThrow an error if geographic_level values used in the data file are not present in the list of acceptable geographic levels
See also
Other precheck_geog:
precheck_geog_level_present()
Examples
precheck_geog_level(example_data)
#> check result message guidance_url
#> 1 geog_level PASS The geographic_level values are all valid. NA
precheck_geog_level(example_data, verbose = TRUE)
#> ✔ The geographic_level values are all valid.
#> check result message guidance_url
#> 1 geog_level PASS The geographic_level values are all valid. NA