Skip to contents

Check that all time_period values are numeric.

Usage

precheck_time_period_num(data, verbose = FALSE, stop_on_error = FALSE)

Arguments

data

A data frame of the data file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

See also

Examples

precheck_time_period_num(example_data)
#>             check result                                              message
#> 1 time_period_num   PASS The time_period column only contains numeric values.
#>   guidance_url
#> 1           NA