Skip to contents

A vector of time identifier values that should have 6 digit numbers. This is a subset of the acceptable_time_ids list.

Usage

six_digit_identifiers

Format

A vector of time identifier values that should have 6 digit numbers

maintained by explore.statistics@education.gov.uk