Check if column labels exceed a character limit
Source:R/check_api_char_limit.R
check_api_char_col_label.RdUses the api_char_limit function to check if any column labels in the
provided metadata frame exceed the character limit specified in the
api_char_limits data frame.
See also
Other check_api:
check_api_char_col_name(),
check_api_char_filter_items(),
check_api_char_loc_code()