Check if filter items or location names exceed character limit
Source:R/check_api_char_limit.R
check_api_char_filter_items.RdChecks if any values in filters, filter groups, or location names exceed the
character limit specified in the api_char_limits data frame, using the
api_char_limit function.
Arguments
- data
A data frame of the data file
- meta
A data frame of the metadata file
- verbose
logical, if TRUE prints feedback messages to console for every test, if FALSE run silently
- stop_on_error
logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"
See also
Other check_api:
check_api_char_col_label(),
check_api_char_col_name(),
check_api_char_loc_code()