Check if location codes exceed a character limit
Source:R/check_api_char_limit.R
check_api_char_loc_code.RdUses the api_char_limit function to check if any location codes in the
provided metadata frame exceed the character limit specified in the
api_char_limits data frame.
See also
Other check_api:
check_api_char_col_label(),
check_api_char_col_name(),
check_api_char_filter_items()