Check that no indicator column names contain typical filter entries
Source:R/check_col_ind_smushed.R
check_col_ind_smushed.RdChecks the metadata file for any indicators that appear to be 'smushed'. Flags any indicator col_name that contains common filter entries (e.g. male, female, asian, black, etc), which suggests the data may not conform to tidy data principles and should instead be pivoted longer with a filter column to contain the characteristic choices.
See also
Other check_col:
check_col_snake_case(),
check_col_var_characteristic(),
check_col_var_start()
Examples
check_col_ind_smushed(example_meta)
#> check result message
#> 1 col_ind_smushed PASS No indicators found containing typical filter entries.
#> guidance_url
#> 1 NA
check_col_ind_smushed(example_meta, verbose = TRUE)
#> ✔ No indicators found containing typical filter entries.
#> check result message
#> 1 col_ind_smushed PASS No indicators found containing typical filter entries.
#> guidance_url
#> 1 NA