Check that column names follow snake_case convention
Source:R/check_col_snake_case.R
check_col_snake_case.RdCheck if all column names in the data file follow the snake_case convention (lowercase letters, numbers, and underscores only). Flags any capital letters or special characters as a warning.
Examples
check_col_snake_case(example_data)
#> check result
#> 1 col_snake_case PASS
#> message
#> 1 The variable names in the data file follow the snake_case convention.
#> guidance_url
#> 1 NA
check_col_snake_case(example_data, verbose = TRUE)
#> ✔ The variable names in the data file follow the snake_case convention.
#> check result
#> 1 col_snake_case PASS
#> message
#> 1 The variable names in the data file follow the snake_case convention.
#> guidance_url
#> 1 NA