Check for characteristic or characteristic_group variable names
Source:R/check_col_var_characteristic.R
check_col_var_characteristic.RdCheck whether the fields 'characteristic' or 'characteristic_group' have been included in the metadata. These are not recommended for use with the EES Table Tool.
See also
Other check_col:
check_col_ind_smushed(),
check_col_snake_case(),
check_col_var_start()
Examples
check_col_var_characteristic(example_meta)
#> check result
#> 1 col_var_characteristic PASS
#> message
#> 1 Neither 'characteristic' nor 'characteristic_group' were found as listed fields in the metadata file.
#> guidance_url
#> 1 NA
check_col_var_characteristic(example_meta, verbose = TRUE)
#> ✔ Neither 'characteristic' nor 'characteristic_group' were found as listed fields in the metadata file.
#> check result
#> 1 col_var_characteristic PASS
#> message
#> 1 Neither 'characteristic' nor 'characteristic_group' were found as listed fields in the metadata file.
#> guidance_url
#> 1 NA