Check that variable names start with a lowercase letter
Source:R/check_col_var_start.R
check_col_var_start.RdCheck that all variable names in the data file start with a lowercase letter. Flags any variables that start with a non-lowercase character as a warning.
See also
Other check_col:
check_col_ind_smushed(),
check_col_snake_case(),
check_col_var_characteristic()
Examples
check_col_var_start(example_data)
#> check result
#> 1 col_var_start PASS
#> message
#> 1 All variable names in the data file start with a lowercase letter.
#> guidance_url
#> 1 NA
check_col_var_start(example_data, verbose = TRUE)
#> ✔ All variable names in the data file start with a lowercase letter.
#> check result
#> 1 col_var_start PASS
#> message
#> 1 All variable names in the data file start with a lowercase letter.
#> guidance_url
#> 1 NA