Check col_names against the data dictionary
Source:R/check_data_dictionary.R
check_data_dict_col_name.RdValidates that the filter and indicator column names in the metadata are present in the data dictionary. Columns not in the data dictionary should not be used in API data sets.
See also
Other check_data_dict:
check_data_dict_fil_item()
Examples
check_data_dict_col_name(example_meta)
#> check result
#> 1 data_dict_col_name PASS
#> message guidance_url
#> 1 All col_names are consistent with the data dictionary. NA
check_data_dict_col_name(example_meta, verbose = TRUE)
#> ✔ All col_names are consistent with the data dictionary.
#> check result
#> 1 data_dict_col_name PASS
#> message guidance_url
#> 1 All col_names are consistent with the data dictionary. NA