Check filenames line up between data and metadata files
Source:R/check_filter_defaults.R
check_filter_defaults.RdMaking sure the data and metadata file follow the pattern of:
datafile.csv (data file)
datafile.meta.csv (metadata file)
Arguments
- data
A character string of the data filename to check
- meta
A character string of the metadata filename to check
- verbose
logical, if TRUE prints feedback messages to console for every test, if FALSE run silently
- stop_on_error
logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"
See also
Other check_filter:
check_filter_item_limit(),
check_filter_whitespace()