Checks for null-like values (such as "NULL", "NA", and similar) in the data and metadata files, and for legacy no-data symbols (such as "N/A", ".", "..") in the data file.
Arguments
- data
A data frame of the data file
- meta
A data frame of the metadata file
- verbose
logical, if TRUE prints feedback messages to console for every test, if FALSE run silently
- stop_on_error
logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"
Details
Null-like symbols cause a failure; finding legacy no-data symbols produces a warning. The GSS provides guidance on the accepted symbols to use for representing missing or suppressed data.
See also
Other check_general:
check_general_dupes()