Check for rows ignored by the EES table tool
Source:R/check_geog_ignored_rows.R
check_geog_ignored_rows.RdIdentifies rows at geographic levels that are ignored by the EES table tool: School, Provider, Institution, and Planning area. Highlights in the message if any such rows are present alongside other levels, and fails if:
School and Provider data have been mixed together OR
The file only contains Planning area or Institution data
See also
Other check_geog:
check_geog_country_combos(),
check_geog_eda_combos(),
check_geog_la_col_present(),
check_geog_la_combos(),
check_geog_lad_combos(),
check_geog_lep_combos(),
check_geog_level_completed(),
check_geog_lsip_combos(),
check_geog_na(),
check_geog_na_code(),
check_geog_other_code_dupes(),
check_geog_other_dupes(),
check_geog_overcompleted_cols(),
check_geog_pcon_combos(),
check_geog_region_col_present(),
check_geog_region_combos(),
check_geog_region_for_la(),
check_geog_region_for_lad(),
check_geog_ward_combos()