Check that all local authority columns are present together
Source:R/check_geog_col_present.R
check_geog_la_col_present.RdWhen any of the three local authority columns (new_la_code, la_name,
old_la_code) appear in the data file, all three must be present. A partial
set of LA columns indicates a data quality issue.
See also
Other check_geog:
check_geog_country_combos(),
check_geog_eda_combos(),
check_geog_ignored_rows(),
check_geog_la_combos(),
check_geog_lad_combos(),
check_geog_lep_combos(),
check_geog_level_completed(),
check_geog_lsip_combos(),
check_geog_na(),
check_geog_na_code(),
check_geog_other_code_dupes(),
check_geog_other_dupes(),
check_geog_overcompleted_cols(),
check_geog_pcon_combos(),
check_geog_region_col_present(),
check_geog_region_combos(),
check_geog_region_for_la(),
check_geog_region_for_lad(),
check_geog_ward_combos()
Examples
check_geog_la_col_present(example_data)
#> check result
#> 1 geog_la_col_present PASS
#> message guidance_url
#> 1 No local authority columns are present in this data file. NA
check_geog_la_col_present(example_data, verbose = TRUE)
#> ✔ No local authority columns are present in this data file.
#> check result
#> 1 geog_la_col_present PASS
#> message guidance_url
#> 1 No local authority columns are present in this data file. NA