Checks that for geographic levels with code and name column pairs, any location with a name of 'Not available' has the corresponding GSS not-available code 'x'. Levels without a code column (RSC region) and levels with their own combo lookups (National, Regional etc) are excluded. Rows at Institution and Planning area level are also excluded as they are ignored by EES.
See also
Other check_geog:
check_geog_country_combos(),
check_geog_eda_combos(),
check_geog_ignored_rows(),
check_geog_la_col_present(),
check_geog_la_combos(),
check_geog_lad_combos(),
check_geog_lep_combos(),
check_geog_level_completed(),
check_geog_lsip_combos(),
check_geog_na(),
check_geog_other_code_dupes(),
check_geog_other_dupes(),
check_geog_overcompleted_cols(),
check_geog_pcon_combos(),
check_geog_region_col_present(),
check_geog_region_combos(),
check_geog_region_for_la(),
check_geog_region_for_lad(),
check_geog_ward_combos()
Examples
check_geog_na_code(example_data)
#> check result
#> 1 geog_na_code PASS
#> message
#> 1 No applicable geographic levels to check for 'Not available' codes.
#> guidance_url
#> 1 NA
check_geog_na_code(example_data, verbose = TRUE)
#> ✔ No applicable geographic levels to check for 'Not available' codes.
#> check result
#> 1 geog_na_code PASS
#> message
#> 1 No applicable geographic levels to check for 'Not available' codes.
#> guidance_url
#> 1 NA