Check for geography name to code duplicates in lower-level geographies
Source:R/check_geog_other_dupes.R
check_geog_other_dupes.RdChecks that each geography name maps to only one code for Opportunity area, MAT, and Sponsor rows. A geography name with multiple different codes indicates a data quality issue.
Details
If none of the lower-level geography levels (Opportunity area, MAT, Sponsor) are present in the data, the check passes immediately.
See also
Other check_geog:
check_geog_country_combos(),
check_geog_eda_combos(),
check_geog_ignored_rows(),
check_geog_la_col_present(),
check_geog_la_combos(),
check_geog_lad_combos(),
check_geog_lep_combos(),
check_geog_level_completed(),
check_geog_lsip_combos(),
check_geog_na(),
check_geog_na_code(),
check_geog_other_code_dupes(),
check_geog_overcompleted_cols(),
check_geog_pcon_combos(),
check_geog_region_col_present(),
check_geog_region_combos(),
check_geog_region_for_la(),
check_geog_region_for_lad(),
check_geog_ward_combos()
Examples
check_geog_other_dupes(example_data)
#> check result
#> 1 geog_other_dupes PASS
#> message guidance_url
#> 1 Lower-level geography data is not present in this data file. NA
check_geog_other_dupes(example_data, verbose = TRUE)
#> ✔ Lower-level geography data is not present in this data file.
#> check result
#> 1 geog_other_dupes PASS
#> message guidance_url
#> 1 Lower-level geography data is not present in this data file. NA