Check parliamentary constituency code and name combinations
Source:R/check_geog_combos.R
check_geog_pcon_combos.RdChecks that all pcon_code and pcon_name combinations in the data file are valid. For Parliamentary constituency rows, all combinations must be valid. For non-PCON rows, only non-empty, non-NA combinations are checked. Rows where pcon_code is "x" (the GSS not-available code) are excluded from non-PCON checks.
See also
Other check_geog:
check_geog_country_combos(),
check_geog_eda_combos(),
check_geog_ignored_rows(),
check_geog_la_col_present(),
check_geog_la_combos(),
check_geog_lad_combos(),
check_geog_lep_combos(),
check_geog_level_completed(),
check_geog_lsip_combos(),
check_geog_na(),
check_geog_na_code(),
check_geog_other_code_dupes(),
check_geog_other_dupes(),
check_geog_overcompleted_cols(),
check_geog_region_col_present(),
check_geog_region_combos(),
check_geog_region_for_la(),
check_geog_region_for_lad(),
check_geog_ward_combos()
Examples
check_geog_pcon_combos(example_data)
#> check result
#> 1 geog_pcon_combos PASS
#> message
#> 1 At least one of the pcon_code / pcon_name columns is not present in this data file.
#> guidance_url
#> 1 NA
check_geog_pcon_combos(example_data, verbose = TRUE)
#> ✔ At least one of the pcon_code / pcon_name columns is not present in this data file.
#> check result
#> 1 geog_pcon_combos PASS
#> message
#> 1 At least one of the pcon_code / pcon_name columns is not present in this data file.
#> guidance_url
#> 1 NA