Check region code and name columns are both present
Source:R/check_geog_col_present.R
check_geog_region_col_present.RdWhen one of region_code or region_name is present in the data file,
checks that the other column is also present. If neither column is present,
the check passes immediately.
See also
Other check_geog:
check_geog_country_combos(),
check_geog_eda_combos(),
check_geog_ignored_rows(),
check_geog_la_col_present(),
check_geog_la_combos(),
check_geog_lad_combos(),
check_geog_lep_combos(),
check_geog_level_completed(),
check_geog_lsip_combos(),
check_geog_na(),
check_geog_na_code(),
check_geog_other_code_dupes(),
check_geog_other_dupes(),
check_geog_overcompleted_cols(),
check_geog_pcon_combos(),
check_geog_region_combos(),
check_geog_region_for_la(),
check_geog_region_for_lad(),
check_geog_ward_combos()
Examples
check_geog_region_col_present(example_data)
#> check result
#> 1 geog_region_col_present PASS
#> message guidance_url
#> 1 No regional columns are present in this data file. NA
check_geog_region_col_present(example_data, verbose = TRUE)
#> ✔ No regional columns are present in this data file.
#> check result
#> 1 geog_region_col_present PASS
#> message guidance_url
#> 1 No regional columns are present in this data file. NA