Check that region columns are complete for Local authority rows
Source:R/check_geog_region_for.R
check_geog_region_for_la.RdChecks that region_code and region_name columns are present in the data
file and contain no missing values for rows at the Local authority geographic
level. Regional information should ideally be provided for all Local
authority level data.
See also
Other check_geog:
check_geog_country_combos(),
check_geog_eda_combos(),
check_geog_ignored_rows(),
check_geog_la_col_present(),
check_geog_la_combos(),
check_geog_lad_combos(),
check_geog_lep_combos(),
check_geog_level_completed(),
check_geog_lsip_combos(),
check_geog_na(),
check_geog_na_code(),
check_geog_other_code_dupes(),
check_geog_other_dupes(),
check_geog_overcompleted_cols(),
check_geog_pcon_combos(),
check_geog_region_col_present(),
check_geog_region_combos(),
check_geog_region_for_lad(),
check_geog_ward_combos()