Check ethnicity column values against GSS standards
Source:R/check_harmonised.R
check_harmonised_eth_vals.RdValidates that the values in ethnicity_major and/or ethnicity_minor
columns in the data file conform to the GSS ethnicity standards. When both
columns are present, major and minor value pairs are checked together.
When only one column is present, its values are checked independently.
See also
Other check_harmonised:
check_harmonised_eth_char_grp(),
check_harmonised_eth_char_vals(),
check_harmonised_variables()
Examples
check_harmonised_eth_vals(example_data)
#> check result message guidance_url
#> 1 harmonised_eth_vals PASS No ethnicity columns found. NA
check_harmonised_eth_vals(example_data, verbose = TRUE)
#> ✔ No ethnicity columns found.
#> check result message guidance_url
#> 1 harmonised_eth_vals PASS No ethnicity columns found. NA