Check filter groups are unique when stripping non-alphanumeric characters
Source:R/check_meta_filter_group_stripped.R
check_meta_filter_group_stripped.RdThrow error when there are not the same number of unique filter groups when they are stripped of characters that are not alpha-numeric
Arguments
- data
A data frame of the data file
- meta
A data frame of the metadata file
- verbose
logical, if TRUE prints feedback messages to console for every test, if FALSE run silently
- stop_on_error
logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"
See also
Other check_meta:
check_meta_col_name_duplicate(),
check_meta_duplicate_label(),
check_meta_filter_group(),
check_meta_filter_group_duplicate(),
check_meta_filter_group_is_filter(),
check_meta_filter_group_match(),
check_meta_filter_hint(),
check_meta_geog_catch(),
check_meta_ind_dp_set(),
check_meta_ind_dp_values(),
check_meta_ind_unit(),
check_meta_ind_unit_validation(),
check_meta_indicator_dp(),
check_meta_indicator_grouping(),
check_meta_label()
Examples
check_meta_filter_group_stripped(example_data, example_meta)
#> check result message guidance_url
#> 1 filter_group_stripped PASS There are no filter groups present. NA
check_meta_filter_group_stripped(example_data, example_meta, verbose = TRUE)
#> ✔ There are no filter groups present.
#> check result message guidance_url
#> 1 filter_group_stripped PASS There are no filter groups present. NA