Skip to contents

This function checks that The indicator_dp column only contains blanks or positive integer values.

Usage

check_meta_ind_dp_values(meta, verbose = FALSE, stop_on_error = FALSE)

Arguments

meta

A data frame of the metadata file

verbose

logical, if TRUE prints feedback messages to console for every test, if FALSE run silently

stop_on_error

logical, if TRUE will stop with an error if the result is "FAIL", and will throw genuine warning if result is "WARNING"

Value

a single row data frame

Examples

check_meta_ind_dp_values(example_meta)
#>           check result
#> 1 ind_dp_values   PASS
#>                                                                           message
#> 1 The indicator_dp column only contains blanks, zero, or positive integer values.
#>   guidance_url
#> 1           NA
check_meta_ind_dp_values(example_meta, verbose = TRUE)
#>  The indicator_dp column only contains blanks, zero, or positive integer values.
#>           check result
#> 1 ind_dp_values   PASS
#>                                                                           message
#> 1 The indicator_dp column only contains blanks, zero, or positive integer values.
#>   guidance_url
#> 1           NA