Check indicator_dp only contains blanks or positive integer values.
Source:R/check_meta_ind_dp_values.R
check_meta_ind_dp_values.RdThis function checks that The indicator_dp column only contains blanks or positive integer values.
See also
Other check_meta:
check_meta_col_name_duplicate(),
check_meta_duplicate_label(),
check_meta_filter_group(),
check_meta_filter_group_duplicate(),
check_meta_filter_group_is_filter(),
check_meta_filter_group_match(),
check_meta_filter_group_stripped(),
check_meta_filter_hint(),
check_meta_geog_catch(),
check_meta_ind_dp_set(),
check_meta_ind_unit(),
check_meta_ind_unit_validation(),
check_meta_indicator_dp(),
check_meta_indicator_grouping(),
check_meta_label()
Examples
check_meta_ind_dp_values(example_meta)
#> check result
#> 1 ind_dp_values PASS
#> message
#> 1 The indicator_dp column only contains blanks, zero, or positive integer values.
#> guidance_url
#> 1 NA
check_meta_ind_dp_values(example_meta, verbose = TRUE)
#> ✔ The indicator_dp column only contains blanks, zero, or positive integer values.
#> check result
#> 1 ind_dp_values PASS
#> message
#> 1 The indicator_dp column only contains blanks, zero, or positive integer values.
#> guidance_url
#> 1 NA