Check that time periods match the time identifier
Source:R/check_time_period.R
check_time_period.RdEvery time identifier is only compatible with either 4 or 6 digit time periods.
See also
Other check_time:
check_time_period_six()
R/check_time_period.R
check_time_period.RdEvery time identifier is only compatible with either 4 or 6 digit time periods.
Other check_time:
check_time_period_six()