A data frame mapping search strings (regex fragments) to the corresponding standard harmonised column names. Used to detect column names that appear to relate to a harmonised variable but do not use the standard name.
A data frame mapping search strings (regex fragments) to the corresponding standard harmonised column names. Used to detect column names that appear to relate to a harmonised variable but do not use the standard name.