Time identifiers that should have 6 digit numbers
Source:R/reference_values.R
six_digit_identifiers.RdA vector of time identifier values that should have 6 digit numbers. This is a subset of the acceptable_time_ids list.
R/reference_values.R
six_digit_identifiers.RdA vector of time identifier values that should have 6 digit numbers. This is a subset of the acceptable_time_ids list.